@@ -15,6 +15,7 @@
 """Flags and helpers for the compute interconnects commands."""
 
 import collections
+import copy
 
 from googlecloudsdk.calliope import arg_parsers
 from googlecloudsdk.calliope import base
@@ -149,17 +150,21 @@ def AddEnableAdmin(parser):
       """)
 
 
-def AddBandwidth(parser, required):
+def AddBandwidth(parser, required, release_track=base.ReleaseTrack.GA):
   """Adds bandwidth flag to the argparse.ArgumentParser.
 
   Args:
     parser: The argparse parser.
     required: A boolean indicates whether the Bandwidth is required.
+    release_track: Depending on which release track is specified, different
+      bandwidth options will be surfaced to customers.
   """
   help_text = """\
       Provisioned capacity of the attachment.
       """
-  choices = _BANDWIDTH_CHOICES
+  choices = copy.deepcopy(_BANDWIDTH_CHOICES)
+  if release_track == base.ReleaseTrack.ALPHA:
+    choices['400g'] = '400 Gbit/s'
 
   base.ChoiceArgument(
       '--bandwidth',
@@ -570,12 +575,13 @@ def AddSubnetLength(parser):
       """)
 
 
-def AddGeneveVni(parser):
+def AddGeneveVni(parser, required=True):
   """Adds geneve vni flag to the argparse.ArgumentParser."""
   parser.add_argument(
       '--geneve-vni',
       metavar='GENEVE_HEADER',
       type=int,
+      required=required,
       help="""A VNI identier for Geneve header, as defined in
       https://datatracker.ietf.org/doc/html/rfc8926, used for L2 forwarding.""",
   )
