@@ -666,10 +666,14 @@ class _BaseInstances(object):
           sql_messages, STORAGE_TYPE_MAPPING.get(args.storage_type)
       )
 
-    if args.active_directory_domain is not None:
-      settings.activeDirectoryConfig = reducers.ActiveDirectoryConfig(
-          sql_messages, args.active_directory_domain
-      )
+    settings.activeDirectoryConfig = reducers.ActiveDirectoryConfig(
+        sql_messages,
+        domain=args.active_directory_domain,
+        mode=args.active_directory_mode,
+        dns_servers=args.active_directory_dns_servers,
+        admin_credential_secret_key=args.active_directory_secret_manager_key,
+        organizational_unit=args.active_directory_organizational_unit,
+    )
 
     if args.IsKnownAndSpecified('password_policy_min_length'):
       settings.passwordValidationPolicy = reducers.PasswordPolicy(
@@ -750,7 +754,15 @@ class _BaseInstances(object):
 
     # ALPHA args.
     if _IsAlpha(release_track):
-      pass
+      read_pool_auto_scale_config = reducers.ReadPoolAutoScaleConfig(
+          sql_messages,
+          auto_scale_enabled=args.auto_scale_enabled,
+          auto_scale_min_node_count=args.auto_scale_min_node_count,
+          auto_scale_max_node_count=args.auto_scale_max_node_count,
+          auto_scale_target_metrics=args.auto_scale_target_metrics,
+      )
+      if read_pool_auto_scale_config is not None:
+        settings.readPoolAutoScaleConfig = read_pool_auto_scale_config
 
     return settings
 
@@ -843,10 +855,14 @@ class _BaseInstances(object):
         insights_config_query_plans_per_minute=args.insights_config_query_plans_per_minute,
     )
 
-    if args.active_directory_domain is not None:
-      settings.activeDirectoryConfig = reducers.ActiveDirectoryConfig(
-          sql_messages, args.active_directory_domain
-      )
+    settings.activeDirectoryConfig = reducers.ActiveDirectoryConfig(
+        sql_messages,
+        domain=args.active_directory_domain,
+        mode=args.active_directory_mode,
+        dns_servers=args.active_directory_dns_servers,
+        admin_credential_secret_key=args.active_directory_secret_manager_key,
+        organizational_unit=args.active_directory_organizational_unit,
+    )
 
     settings.passwordValidationPolicy = reducers.PasswordPolicy(
         sql_messages,
@@ -892,6 +908,21 @@ class _BaseInstances(object):
     if updated_config is not None:
       settings.connectionPoolConfig = updated_config
 
+    if args.IsKnownAndSpecified('psc_auto_connections'):
+      if not settings.ipConfiguration:
+        settings.ipConfiguration = sql_messages.IpConfiguration()
+      if not settings.ipConfiguration.pscConfig:
+        settings.ipConfiguration.pscConfig = sql_messages.PscConfig()
+      settings.ipConfiguration.pscConfig.pscAutoConnections = (
+          reducers.PscAutoConnections(sql_messages, args.psc_auto_connections)
+      )
+    if args.IsKnownAndSpecified('clear_psc_auto_connections'):
+      if not settings.ipConfiguration:
+        settings.ipConfiguration = sql_messages.IpConfiguration()
+      if not settings.ipConfiguration.pscConfig:
+        settings.ipConfiguration.pscConfig = sql_messages.PscConfig()
+      settings.ipConfiguration.pscConfig.pscAutoConnections = []
+
     # BETA args.
     if IsBetaOrNewer(release_track):
       labels_diff = labels_util.ExplicitNullificationDiff.FromUpdateArgs(args)
@@ -908,29 +939,25 @@ class _BaseInstances(object):
           settings.ipConfiguration = sql_messages.IpConfiguration()
         settings.ipConfiguration.allocatedIpRange = args.allocated_ip_range_name
 
-      if args.IsKnownAndSpecified('psc_auto_connections'):
-        if not settings.ipConfiguration:
-          settings.ipConfiguration = sql_messages.IpConfiguration()
-        if not settings.ipConfiguration.pscConfig:
-          settings.ipConfiguration.pscConfig = sql_messages.PscConfig()
-        settings.ipConfiguration.pscConfig.pscAutoConnections = (
-            reducers.PscAutoConnections(
-                sql_messages, args.psc_auto_connections
-            )
-        )
-      if args.IsKnownAndSpecified('clear_psc_auto_connections'):
-        if not settings.ipConfiguration:
-          settings.ipConfiguration = sql_messages.IpConfiguration()
-        if not settings.ipConfiguration.pscConfig:
-          settings.ipConfiguration.pscConfig = sql_messages.PscConfig()
-        settings.ipConfiguration.pscConfig.pscAutoConnections = []
-
       if args.IsKnownAndSpecified('unc_mappings'):
         settings.uncMappings = reducers.UncMappings(
             sql_messages,
             unc_mappings=args.unc_mappings,
             clear_unc_mappings=args.clear_unc_mappings,
         )
+    # ALPHA args.
+    if _IsAlpha(release_track):
+      read_pool_auto_scale_config = reducers.ReadPoolAutoScaleConfig(
+          sql_messages,
+          auto_scale_enabled=args.auto_scale_enabled,
+          auto_scale_min_node_count=args.auto_scale_min_node_count,
+          auto_scale_max_node_count=args.auto_scale_max_node_count,
+          auto_scale_target_metrics=args.auto_scale_target_metrics,
+          auto_scale_disable_scale_in=args.auto_scale_disable_scale_in,
+          current_config=original_settings.readPoolAutoScaleConfig,
+      )
+      if read_pool_auto_scale_config is not None:
+        settings.readPoolAutoScaleConfig = read_pool_auto_scale_config
     return settings
 
   @classmethod
@@ -1193,9 +1220,7 @@ class _BaseInstances(object):
 
     if args.IsKnownAndSpecified('failover_dr_replica_name'):
       replication_cluster = sql_messages.ReplicationCluster()
-      replication_cluster.failoverDrReplicaName = (
-          args.failover_dr_replica_name
-      )
+      replication_cluster.failoverDrReplicaName = args.failover_dr_replica_name
       instance_resource.replicationCluster = replication_cluster
     if args.IsKnownAndSpecified('clear_failover_dr_replica_name'):
       if instance_resource.replicationCluster is not None:
