@@ -122,6 +122,8 @@ def _CommonArgs(
     support_disk_labels=False,
     support_source_snapshot_region=False,
     support_skip_guest_os_shutdown=False,
+    support_preemption_notice_duration=False,
+    support_enable_vpc_scoped_dns=False,
 ):
   """Register parser args common to all tracks."""
   metadata_utils.AddMetadataArgs(parser)
@@ -149,7 +151,9 @@ def _CommonArgs(
       support_network_queue_count=support_network_queue_count,
       support_vlan_nic=support_vlan_nic,
       support_ipv6_only=support_ipv6_only,
-      support_igmp_query=support_igmp_query)
+      support_igmp_query=support_igmp_query,
+      support_enable_vpc_scoped_dns=support_enable_vpc_scoped_dns,
+  )
   instances_flags.AddAcceleratorArgs(parser)
   instances_flags.AddMachineTypeArgs(parser)
   instances_flags.AddMaintenancePolicyArgs(
@@ -258,6 +262,9 @@ def _CommonArgs(
     instances_flags.AddMaxRunDurationVmArgs(parser)
     instances_flags.AddDiscardLocalSsdVmArgs(parser)
 
+  if support_preemption_notice_duration:
+    instances_flags.AddPreemptionNoticeDurationArgs(parser)
+
   if support_local_ssd_size:
     instances_flags.AddLocalSsdArgsWithSize(parser)
   else:
@@ -269,6 +276,7 @@ def _CommonArgs(
   instances_flags.AddTurboModeArgs(parser)
   if support_skip_guest_os_shutdown:
     instances_flags.AddSkipGuestOsShutdownArgs(parser)
+  instances_flags.AddRequestValidForDurationArgs(parser)
 
 
 @base.UniverseCompatible
@@ -276,6 +284,7 @@ def _CommonArgs(
 class Create(base.CreateCommand):
   """Create Compute Engine virtual machine instances."""
 
+  # TODO(b/445859137): clean up flags which are true in all tracks.
   _support_regional = True
   _support_kms = True
   _support_nvdimm = False
@@ -320,7 +329,9 @@ class Create(base.CreateCommand):
   _support_disk_labels = False
   _support_ipv6_only = True
   _support_source_snapshot_region = False
-  _support_skip_guest_os_shutdown = False
+  _support_skip_guest_os_shutdown = True
+  _support_preemption_notice_duration = False
+  _support_enable_vpc_scoped_dns = False
 
   @classmethod
   def Args(cls, parser):
@@ -349,6 +360,8 @@ class Create(base.CreateCommand):
         support_ipv6_only=cls._support_ipv6_only,
         support_source_snapshot_region=cls._support_source_snapshot_region,
         support_skip_guest_os_shutdown=cls._support_skip_guest_os_shutdown,
+        support_preemption_notice_duration=cls._support_preemption_notice_duration,
+        support_enable_vpc_scoped_dns=cls._support_enable_vpc_scoped_dns,
     )
     cls.SOURCE_INSTANCE_TEMPLATE = (
         instances_flags.MakeSourceInstanceTemplateArg()
@@ -373,7 +386,7 @@ class Create(base.CreateCommand):
     instances_flags.AddPerformanceMonitoringUnitArgs(parser)
     instances_flags.AddProvisioningModelVmArgs(
         parser,
-        support_flex_start=False,
+        support_flex_start=True,
     )
 
   def Collection(self):
@@ -423,6 +436,7 @@ class Create(base.CreateCommand):
         support_local_ssd_recovery_timeout=self._support_local_ssd_recovery_timeout,
         support_graceful_shutdown=self._support_graceful_shutdown,
         support_skip_guest_os_shutdown=self._support_skip_guest_os_shutdown,
+        support_preemption_notice_duration=self._support_preemption_notice_duration,
     )
     tags = instance_utils.GetTags(args, compute_client)
     labels = instance_utils.GetLabels(args, compute_client)
@@ -441,6 +455,7 @@ class Create(base.CreateCommand):
         support_public_dns=self._support_public_dns,
         support_ipv6_assignment=self._support_ipv6_assignment,
         support_internal_ipv6_reservation=self._support_internal_ipv6_reservation,
+        support_enable_vpc_scoped_dns=self._support_enable_vpc_scoped_dns,
     )
 
     confidential_vm_type = instance_utils.GetConfidentialVmType(
@@ -836,6 +851,8 @@ class CreateBeta(Create):
   _support_ipv6_only = True
   _support_source_snapshot_region = True
   _support_skip_guest_os_shutdown = True
+  _support_preemption_notice_duration = False
+  _support_enable_vpc_scoped_dns = False
 
   def GetSourceMachineImage(self, args, resources):
     """Retrieves the specified source machine image's selflink.
@@ -880,6 +897,8 @@ class CreateBeta(Create):
         support_ipv6_only=cls._support_ipv6_only,
         support_source_snapshot_region=cls._support_source_snapshot_region,
         support_skip_guest_os_shutdown=cls._support_skip_guest_os_shutdown,
+        support_preemption_notice_duration=cls._support_preemption_notice_duration,
+        support_enable_vpc_scoped_dns=cls._support_enable_vpc_scoped_dns,
     )
     cls.SOURCE_INSTANCE_TEMPLATE = (
         instances_flags.MakeSourceInstanceTemplateArg()
@@ -905,7 +924,7 @@ class CreateBeta(Create):
     instances_flags.AddPerformanceMonitoringUnitArgs(parser)
     instances_flags.AddProvisioningModelVmArgs(
         parser,
-        support_flex_start=False,
+        support_flex_start=True,
     )
     partner_metadata_utils.AddPartnerMetadataArgs(parser)
 
@@ -958,6 +977,8 @@ class CreateAlpha(CreateBeta):
   _support_disk_labels = True
   _support_source_snapshot_region = True
   _support_skip_guest_os_shutdown = True
+  _support_preemption_notice_duration = True
+  _support_enable_vpc_scoped_dns = True
 
   @classmethod
   def Args(cls, parser):
@@ -990,6 +1011,8 @@ class CreateAlpha(CreateBeta):
         support_disk_labels=cls._support_disk_labels,
         support_source_snapshot_region=cls._support_source_snapshot_region,
         support_skip_guest_os_shutdown=cls._support_skip_guest_os_shutdown,
+        support_preemption_notice_duration=cls._support_preemption_notice_duration,
+        support_enable_vpc_scoped_dns=cls._support_enable_vpc_scoped_dns,
     )
 
     CreateAlpha.SOURCE_INSTANCE_TEMPLATE = (
@@ -1025,7 +1048,6 @@ class CreateAlpha(CreateBeta):
         support_flex_start=True,
     )
     partner_metadata_utils.AddPartnerMetadataArgs(parser)
-    instances_flags.AddRequestValidForDurationArgs(parser)
 
 
 Create.detailed_help = DETAILED_HELP
