@@ -187,7 +187,14 @@ def ParseCreateOptionsBase(
   """Parses the flags provided with the cluster creation command."""
   flags.MungeBasicAuthFlags(args)
 
-  flags.WarnForUnspecifiedKubeletReadonlyPort()
+  # The readonly port has been disabled by default since 02/2025. We should only
+  # alert users to the risk of this port if they explicitly enable it.
+  enable_insecure_roport = get_default('enable_insecure_kubelet_readonly_port')
+  autoprovisioning_enable_insecure_roport = get_default(
+      'autoprovisioning_enable_insecure_kubelet_readonly_port'
+  )
+  if enable_insecure_roport or autoprovisioning_enable_insecure_roport:
+    flags.WarnForUnspecifiedKubeletReadonlyPort()
 
   flags.WarnForEnablingBetaAPIs(args)
   enable_autorepair = None
@@ -437,6 +444,9 @@ def ParseCreateOptionsBase(
       autoprovisioning_min_cpu_platform=get_default(
           'autoprovisioning_min_cpu_platform'
       ),
+      autopilot_privileged_admission=get_default(
+          'autopilot_privileged_admission'
+      ),
       min_cpu=get_default('min_cpu'),
       max_cpu=get_default('max_cpu'),
       min_memory=get_default('min_memory'),
@@ -482,12 +492,8 @@ def ParseCreateOptionsBase(
       compliance_standards=get_default('compliance_standards'),
       enable_security_posture=get_default('enable_security_posture'),
       network_performance_config=get_default('network_performance_configs'),
-      enable_insecure_kubelet_readonly_port=get_default(
-          'enable_insecure_kubelet_readonly_port'
-      ),
-      autoprovisioning_enable_insecure_kubelet_readonly_port=get_default(
-          'autoprovisioning_enable_insecure_kubelet_readonly_port'
-      ),
+      enable_insecure_kubelet_readonly_port=enable_insecure_roport,
+      autoprovisioning_enable_insecure_kubelet_readonly_port=autoprovisioning_enable_insecure_roport,
       enable_k8s_beta_apis=getattr(args, 'enable_kubernetes_unstable_apis'),
       security_posture=get_default('security_posture'),
       workload_vulnerability_scanning=get_default(
@@ -825,6 +831,9 @@ flags_to_add = {
         'enableK8sCertsViaDns': flags.AddEnableK8sCertsViaDnsFlag,
         'networkTier': flags.AddNetworkTierFlag,
         'controlPlaneEgress': flags.AddControlPlaneEgressFlag,
+        'autopilotPrivilegedAdmission': (
+            lambda p: flags.AddAutopilotPrivilegedAdmissionFlag(p, hidden=True)
+        ),
     },
     BETA: {
         'accelerator': lambda p: AddAcceleratorFlag(p, True, True, True, True),
@@ -939,7 +948,9 @@ flags_to_add = {
         'shieldednodes': flags.AddEnableShieldedNodesFlags,
         'spot': flags.AddSpotFlag,
         'stackdriver': flags.AddEnableStackdriverKubernetesFlag,
-        'stacktype': flags.AddStackTypeFlag,
+        'stacktype': lambda parser: flags.AddStackTypeFlag(
+            parser, release_track=base.ReleaseTrack.BETA
+        ),
         'storagePools': flags.AddStoragePoolsFlag,
         'localSsdEncryptionMode': flags.AddLocalSsdEncryptionModeFlag,
         'dataCacheCount': flags.AddDataCacheCountFlag,
@@ -1027,6 +1038,12 @@ flags_to_add = {
         'enableK8sCertsViaDns': flags.AddEnableK8sCertsViaDnsFlag,
         'networkTier': flags.AddNetworkTierFlag,
         'controlPlaneEgress': flags.AddControlPlaneEgressFlag,
+        'managedOTelScope': lambda p: flags.AddManagedOTelScopeFlags(
+            p, hidden=True
+        ),
+        'autopilotPrivilegedAdmission': (
+            lambda p: flags.AddAutopilotPrivilegedAdmissionFlag(p, hidden=True)
+        ),
     },
     ALPHA: {
         'accelerator': lambda p: AddAcceleratorFlag(p, True, True, True, True),
@@ -1237,6 +1254,12 @@ flags_to_add = {
         'enableK8sCertsViaDns': flags.AddEnableK8sCertsViaDnsFlag,
         'networkTier': flags.AddNetworkTierFlag,
         'controlPlaneEgress': flags.AddControlPlaneEgressFlag,
+        'managedOTelScope': lambda p: flags.AddManagedOTelScopeFlags(
+            p, hidden=True
+        ),
+        'autopilotPrivilegedAdmission': (
+            lambda p: flags.AddAutopilotPrivilegedAdmissionFlag(p, hidden=True)
+        ),
     },
 }
 # LINT.ThenChange(create_auto.py:auto_flags)
@@ -1598,6 +1621,7 @@ class CreateBeta(Create):
     ops.enable_k8s_certs_via_dns = get_default('enable_k8s_certs_via_dns')
     ops.control_plane_egress_mode = get_default('control_plane_egress')
     ops.gpu_direct_strategy = get_default('gpu_direct_strategy')
+    ops.managed_otel_scope = get_default('managed_otel_scope')
     return ops
 
 
@@ -1760,4 +1784,5 @@ class CreateAlpha(Create):
     ops.enable_k8s_certs_via_dns = get_default('enable_k8s_certs_via_dns')
     ops.control_plane_egress_mode = get_default('control_plane_egress')
     ops.gpu_direct_strategy = get_default('gpu_direct_strategy')
+    ops.managed_otel_scope = get_default('managed_otel_scope')
     return ops
