@@ -146,7 +146,7 @@ class Deploy(base.Command):
     flags.AddVpcNetworkGroupFlagsForUpdate(parser)
     flags.RemoveContainersFlag().AddToParser(parser)
     flags.AddVolumesFlags(parser, cls.ReleaseTrack())
-    flags.AddServiceMinInstancesFlag(parser)
+    flags.AddServiceMinMaxInstancesFlag(parser)
     flags.AddInvokerIamCheckFlag(parser)
     flags.AddScalingFlag(parser)
 
@@ -175,6 +175,7 @@ class Deploy(base.Command):
     flags.AddServiceAccountFlag(parser)
     flags.AddClientNameAndVersionFlags(parser)
     flags.AddIngressFlag(parser)
+    flags.AddRegionsArg(parser)
     concept_parsers.ConceptParser([service_presentation]).AddToParser(parser)
     # No output by default, can be overridden by --format
     parser.display_info.AddFormat('none')
@@ -185,18 +186,6 @@ class Deploy(base.Command):
     container_args = ContainerArgGroup(cls.ReleaseTrack())
     container_parser.AddContainerFlags(parser, container_args)
 
-  def _GetAllowUnauthRegions(self, args):
-    """Returns regions to operate on SetIamPolicy for multi-region Services.
-
-    Args:
-      args: argparse.Namespace, Command line arguments
-
-    Returns:
-      None for single-region services, or a list of regions for multi-region
-      services.
-    """
-    return None
-
   def GetAllowUnauth(self, args, operations, service_ref, service_exists):
     """Returns allow_unauth value for a service change.
 
@@ -214,6 +203,29 @@ class Deploy(base.Command):
       False means to disable unauthenticated access for the service.
       None means to retain the current value for the service.
     """
+    if (
+        flags.FlagIsExplicitlySet(args, 'preset')
+        and args.preset['name'] in flags.PRIVATE_ACCESS_PRESETS
+    ):
+      return False
+    if (
+        flags.FlagIsExplicitlySet(args, 'preset')
+        and args.preset['name'] in flags.PUBLIC_ACCESS_PRESETS
+    ):
+      return True
+    if self._IsMultiRegion():
+      allow_unauth = flags.GetAllowUnauthenticated(
+          args,
+          operations,
+          service_ref,
+          not service_exists,
+          region_override=self._GetRegionsForMultiRegion()[0],
+      )
+      # Avoid failure removing a policy binding for a service that
+      # doesn't exist.
+      if not service_exists and not allow_unauth:
+        return None
+      return allow_unauth
     allow_unauth = None
     if platforms.GetPlatform() == platforms.PLATFORM_MANAGED:
       allow_unauth = flags.GetAllowUnauthenticated(
@@ -228,6 +240,21 @@ class Deploy(base.Command):
   def _ValidateAndGetContainers(self, args):
     if flags.FlagIsExplicitlySet(args, 'containers'):
       containers = args.containers
+      # TODO(b/436350694): Change this to use preset metadata once it is
+      # implemented.
+      if (
+          flags.FlagIsExplicitlySet(args, 'preset')
+          and args.preset['name'] in flags.INGRESS_CONTAINER_PRESETS
+      ):
+        specified_args = getattr(
+            containers[args.preset['name']], '_specified_args'
+        )
+        specified_args['image'] = '--image'
+        setattr(
+            containers[args.preset['name']], '_specified_args', specified_args
+        )
+        setattr(containers[args.preset['name']], 'image', 'imageplaceholder')
+        setattr(containers[args.preset['name']], 'automatic_updates', None)
     else:
       containers = {'': args}
 
@@ -250,12 +277,20 @@ class Deploy(base.Command):
     return containers
 
   def _ValidateNoAutomaticUpdatesForContainers(
-      self, build_from_source, containers
+      self, deploy_from_source, containers
   ):
-    pass
+    for name, container in containers.items():
+      if name not in deploy_from_source and container.IsSpecified(
+          'automatic_updates'
+      ):
+        raise c_exceptions.InvalidArgumentException(
+            '--automatic-updates',
+            '--automatic-updates can only be specified in the container that'
+            ' builds from source.',
+        )
 
-  def _ValidateAndGetBuildFromSource(self, containers):
-    build_from_source = {
+  def _ValidateAndGeDeployFromSource(self, containers):
+    deploy_from_source = {
         name: container
         for name, container in containers.items()
         if (
@@ -263,10 +298,10 @@ class Deploy(base.Command):
             or flags.FlagIsExplicitlySet(container, 'source')
         )
     }
-    if len(build_from_source) > 1:
+    if len(deploy_from_source) > 1:
       needs_image = [
           name
-          for name, container in build_from_source.items()
+          for name, container in deploy_from_source.items()
           if not flags.FlagIsExplicitlySet(container, 'source')
       ]
       if needs_image:
@@ -274,8 +309,10 @@ class Deploy(base.Command):
       raise c_exceptions.InvalidArgumentException(
           '--container', 'At most one container can be deployed from source.'
       )
-    self._ValidateNoAutomaticUpdatesForContainers(build_from_source, containers)
-    for name, container in build_from_source.items():
+    self._ValidateNoAutomaticUpdatesForContainers(
+        deploy_from_source, containers
+    )
+    for name, container in deploy_from_source.items():
       if not flags.FlagIsExplicitlySet(container, 'source'):
         if console_io.CanPrompt():
           container.source = flags.PromptForDefaultSource(name)
@@ -296,24 +333,24 @@ class Deploy(base.Command):
               '--image',
               message,
           )
-    self._ValidateNoBuildFromSource(build_from_source)
-    return build_from_source
+    self._ValidateNoBuildFromSource(deploy_from_source)
+    return deploy_from_source
 
-  def _ValidateNoBuildFromSource(self, build_from_source):
+  def _ValidateNoBuildFromSource(self, deploy_from_source):
     """Extra validation for Zip deployments.
 
     This is a no-op for if the --no-build flag is not set.
 
     Args:
-      build_from_source: The build from source map of container name to
+      deploy_from_source: The build from source map of container name to
         container object.
     """
-    if not _IsNoBuildFromSource(self.ReleaseTrack(), build_from_source):
+    if not _IsNoBuildFromSource(self.ReleaseTrack(), deploy_from_source):
       return
 
     # TODO(b/424567464): Remove this check once we support multiple containers
     # with --no-build.
-    container = next(iter(build_from_source.items()))[1]
+    container = next(iter(deploy_from_source.items()))[1]
     if not container.IsSpecified('base_image'):
       raise c_exceptions.InvalidArgumentException(
           '--no-build',
@@ -463,7 +500,7 @@ class Deploy(base.Command):
     changes = []
     source = container_args.source
     source_bucket = (
-        self._GetSourceBucketFromSourceLocation(service.source_location)
+        self._GetSourceBucketFromBuildSourceLocation(service.source_location)
         if service
         else None
     )
@@ -495,7 +532,7 @@ class Deploy(base.Command):
     automatic_updates = self._GetAutomaticUpdates(container_args, service)
 
     build_machine_type = None
-    if self.ReleaseTrack() == base.ReleaseTrack.ALPHA:
+    if self.ReleaseTrack() != base.ReleaseTrack.GA:
       build_machine_type = self._GetMachineType(container_args, service)
 
     if os.path.exists(docker_file):
@@ -625,7 +662,48 @@ class Deploy(base.Command):
       docker_string = ar_repo.GetDockerString()
     return docker_string, repo_to_create
 
-  def _GetSourceBucketFromSourceLocation(self, source_location):
+  def _GetRegionsForMultiRegion(self):
+    if self.__multi_region_regions:
+      return self.__multi_region_regions.split(',')
+    return None
+
+  def _IsMultiRegion(self):
+    return bool(self.__multi_region_regions)
+
+  def _GetSourceBucketFromZipDeploySourceLocation(self, service):
+    """Returns the source bucket from the zip deploy source annotation run.googleapis.com/source.
+
+    If the annotations has more than one entry, return None.
+
+    Args:
+      service: existing Cloud run service.
+    """
+    source_location_map = service.source_deploy_no_build_source_location_map
+    logging.debug('source_location map: %s', source_location_map)
+    if not source_location_map:
+      return None
+    try:
+      container_to_source_map = json.loads(source_location_map)
+      if (
+          not isinstance(container_to_source_map, dict)
+          or len(container_to_source_map) != 1
+      ):
+        logging.debug(
+            'source_location is not a valid map or has more than one entry'
+        )
+        return None
+      x = re.search(
+          r'gs://([^/]+)/.*', next(iter(container_to_source_map.values()))
+      )
+      if x:
+        return x.group(1)
+      logging.debug('source_location does not match pattern gs://([^/]+)/.*')
+      return None
+    except (json.JSONDecodeError, TypeError) as e:
+      logging.debug('failed to parse source location: %s', e)
+      return None
+
+  def _GetSourceBucketFromBuildSourceLocation(self, source_location):
     logging.debug('source_location: %s', source_location)
     if not source_location:
       return None
@@ -647,6 +725,13 @@ class Deploy(base.Command):
     changes.append(
         config_changes.SetLaunchStageAnnotationChange(self.ReleaseTrack())
     )
+    if self._IsMultiRegion():
+      changes.append(
+          # TODO(b/440397578): Use the array here once we merge beta and GA.
+          config_changes.SetRegionsAnnotationChange(
+              regions=self.__multi_region_regions
+          )
+      )
     return changes
 
   def _ConnectionContext(self, args):
@@ -657,6 +742,7 @@ class Deploy(base.Command):
         args,
         flags.Product.RUN,
         self.ReleaseTrack(),
+        is_multiregion=self._IsMultiRegion(),
     )
 
   def _GetTracker(
@@ -684,29 +770,51 @@ class Deploy(base.Command):
         include_build=requires_build,
         include_create_repo=repo_to_create is not None,
         include_iap=iap is not None,
+        regions_list=self._GetRegionsForMultiRegion(),
     )
     if requires_build:
       header = 'Building and deploying'
     else:
       header = 'Deploying'
     if service is None:
-      header += ' new service'
+      header += ' new'
+      if self._IsMultiRegion():
+        header += ' Multi-Region service'
+      else:
+        header += ' service'
       # new services default cpu boost on the client
       if not flags.FlagIsExplicitlySet(args, 'cpu_boost'):
         changes.append(config_changes.StartupCpuBoostChange(cpu_boost=True))
+    if self._IsMultiRegion():
+      failure_message = (
+          'Multi-region deployment failed. Some regions might already be'
+          ' serving traffic.'
+      )
+    else:
+      failure_message = 'Deployment failed'
     header += '...'
     return progress_tracker.StagedProgressTracker(
         header,
         deployment_stages,
-        failure_message='Deployment failed',
+        failure_message=failure_message,
         suppress_output=args.async_,
     )
 
-  def _GetRequiredApis(self, args):
-    return [api_enabler.get_run_api()]
+  def _GetRequiredApis(self, build_from_source):
+    apis = [api_enabler.get_run_api()]
+    if build_from_source:
+      apis.append('artifactregistry.googleapis.com')
+      apis.append('cloudbuild.googleapis.com')
+    return apis
 
   def _DisplaySuccessMessage(self, service, args):
-    if args.async_:
+    if self._IsMultiRegion() and not args.async_:
+      pretty_print.Success(
+          messages_util.GetSuccessMessageForMultiRegionSynchronousDeploy(
+              service, self._GetRegionsForMultiRegion()
+          )
+      )
+    elif args.async_:
       pretty_print.Success(
           'Service [{{bold}}{serv}{{reset}}] is deploying '
           'asynchronously.'.format(serv=service.name)
@@ -726,47 +834,18 @@ class Deploy(base.Command):
 
   def Run(self, args):
     """Deploy a container to Cloud Run."""
+    self.__multi_region_regions = flags.GetMultiRegion(args)
     platform = flags.GetAndValidatePlatform(
         args, self.ReleaseTrack(), flags.Product.RUN
     )
 
     containers = self._ValidateAndGetContainers(args)
-    build_from_source = self._ValidateAndGetBuildFromSource(containers)
+    deploy_from_source = self._ValidateAndGeDeployFromSource(containers)
 
     service_ref = args.CONCEPTS.service.Parse()
     flags.ValidateResource(service_ref)
 
-    required_apis = self._GetRequiredApis(args)
-    if build_from_source:
-      is_cmek_consent_required = (
-          self.ReleaseTrack() == base.ReleaseTrack.GA
-          and flags.FlagIsExplicitlySet(args, 'key')
-          and not flags.FlagIsExplicitlySet(args, 'allow_unencrypted_build')
-      )
-      if is_cmek_consent_required:
-        if not console_io.CanPrompt():
-          raise c_exceptions.ConflictingArgumentsException(
-              '--key',
-              'This source deployment involves a build process which does not'
-              ' support customer-managed encryption keys (CMEK). The current'
-              ' command is executed in a non-interactive session, it cannot'
-              ' prompt the user to acknowledge these limitations. Re-run the'
-              ' command in an interactive session where prompting is'
-              ' available.',
-          )
-        if not console_io.PromptContinue(
-            message=(
-                'This source deployment involves a build process which does'
-                ' not support customer-managed encryption keys (CMEK). If'
-                ' you choose to continue, compliance will be limited to'
-                ' only the deployed container, and will not apply to the'
-                ' build sources and artifacts. Would you like to continue?'
-            )
-        ):
-          return None
-
-      required_apis.append('artifactregistry.googleapis.com')
-      required_apis.append('cloudbuild.googleapis.com')
+    required_apis = self._GetRequiredApis(deploy_from_source)
 
     already_activated_services = False
     if platform == platforms.PLATFORM_MANAGED:
@@ -789,7 +868,7 @@ class Deploy(base.Command):
     build_worker_pool = None
     build_machine_type = None
     build_changes = []
-    build_from_source_container_name = ''
+    deploy_from_source_container_name = ''
     enable_automatic_updates = None
     source_bucket = None
     skip_build = False
@@ -798,20 +877,23 @@ class Deploy(base.Command):
     ) as operations:
       service = operations.GetService(service_ref)
       # Build an image from source if source specified
-      if _IsNoBuildFromSource(self.ReleaseTrack(), build_from_source):
+      if _IsNoBuildFromSource(self.ReleaseTrack(), deploy_from_source):
         image = 'scratch'
         skip_build = True
-        build_from_source_container_name, container_args = next(
-            iter(build_from_source.items())
+        deploy_from_source_container_name, container_args = next(
+            iter(deploy_from_source.items())
         )
         # re-use the existing container name if it is not specified.
-        if not build_from_source_container_name and service:
-          build_from_source_container_name = (
+        if not deploy_from_source_container_name and service:
+          deploy_from_source_container_name = (
               service.template.container.name or ''
           )
         source = container_args.source
+        source_bucket = self._GetSourceBucketFromZipDeploySourceLocation(
+            service
+        )
         container_args.image = 'scratch'
-      elif build_from_source:
+      elif deploy_from_source:
         (
             is_function,
             image,
@@ -822,7 +904,7 @@ class Deploy(base.Command):
             base_image,
             build_service_account,
             build_changes,
-            build_from_source_container_name,
+            deploy_from_source_container_name,
             build_worker_pool,
             build_machine_type,
             build_env_vars,
@@ -830,7 +912,7 @@ class Deploy(base.Command):
             source_bucket,
         ) = self._BuildFromSource(
             args,
-            build_from_source,
+            deploy_from_source,
             service_ref,
             conn_context,
             platform,
@@ -875,7 +957,7 @@ class Deploy(base.Command):
             args,
             service,
             changes_,
-            build_from_source,
+            deploy_from_source,
             repo_to_create,
             allow_unauth,
             has_latest,
@@ -889,7 +971,7 @@ class Deploy(base.Command):
               tracker,
               asyn=args.async_,
               allow_unauthenticated=allow_unauth,
-              allow_unauth_regions=self._GetAllowUnauthRegions(args),
+              multiregion_regions=self._GetRegionsForMultiRegion(),
               prefetch=service,
               build_image=image,
               build_pack=pack,
@@ -905,7 +987,7 @@ class Deploy(base.Command):
                   args, 'delegate_builds'
               ),
               base_image=base_image,
-              build_from_source_container_name=build_from_source_container_name,
+              deploy_from_source_container_name=deploy_from_source_container_name,
               build_service_account=build_service_account,
               build_worker_pool=build_worker_pool,
               build_machine_type=build_machine_type,
@@ -1106,147 +1188,35 @@ def _ShouldClearBuildServiceAccount(args, build_service_account):
 class BetaDeploy(Deploy):
   """Create or update a Cloud Run service."""
 
-  def _ValidateNoAutomaticUpdatesForContainers(
-      self, build_from_source, containers
-  ):
-    for name, container in containers.items():
-      if name not in build_from_source and container.IsSpecified(
-          'automatic_updates'
-      ):
-        raise c_exceptions.InvalidArgumentException(
-            '--automatic-updates',
-            '--automatic-updates can only be specified in the container that'
-            ' is built from source.',
-        )
-
   @classmethod
   def Args(cls, parser):
     cls.CommonArgs(parser)
 
     # Flags specific to managed CR
     flags.AddDeployHealthCheckFlag(parser)
-    flags.AddRegionsArg(parser)
     flags.SERVICE_MESH_FLAG.AddToParser(parser)
     flags.AddIapFlag(parser)
-    flags.AddServiceMaxInstancesFlag(parser)
     container_args = ContainerArgGroup(cls.ReleaseTrack())
     container_parser.AddContainerFlags(parser, container_args)
 
-  def GetAllowUnauth(self, args, operations, service_ref, service_exists):
-    if self.__is_multi_region:
-      allow_unauth = flags.GetAllowUnauthenticated(
-          args,
-          operations,
-          service_ref,
-          not service_exists,
-          region_override=self.__is_multi_region.split(',')[0],
-      )
-      # Avoid failure removing a policy binding for a service that
-      # doesn't exist.
-      if not service_exists and not allow_unauth:
-        return None
-      return allow_unauth
-    return super().GetAllowUnauth(args, operations, service_ref, service_exists)
-
-  def _GetAllowUnauthRegions(self, args):
-    if self.__is_multi_region:
-      return self.__is_multi_region.split(',')
-    return None
-
-  def _DisplaySuccessMessage(self, service, args):
-    if not self.__is_multi_region or args.async_:
-      return super()._DisplaySuccessMessage(service, args)
-
-    pretty_print.Success(
-        messages_util.GetSuccessMessageForMultiRegionSynchronousDeploy(
-            service, self._GetAllowUnauthRegions(args)
-        )
-    )
-
-  def _ConnectionContext(self, args):
-    """Returns the connection context with is_multiregion set."""
-    return connection_context.GetConnectionContext(
-        args,
-        flags.Product.RUN,
-        self.ReleaseTrack(),
-        is_multiregion=self.__is_multi_region,
-    )
-
-  def _GetBaseChanges(self, args):
-    """Returns the service config changes with maybe multi-region annotation."""
-    changes = super()._GetBaseChanges(args)
-    if self.__is_multi_region:
-      changes.append(
-          config_changes.SetRegionsAnnotationChange(
-              regions=self.__is_multi_region
-          )
-      )
-    return changes
-
-  def _GetTracker(
-      self,
-      args,
-      service,
-      changes,
-      build_from_source,
-      repo_to_create,
-      allow_unauth,
-      has_latest,
-      iap,
-      skip_build,
-  ):
-    if not self.__is_multi_region:
-      return super()._GetTracker(
-          args,
-          service,
-          changes,
-          build_from_source,
-          repo_to_create,
-          allow_unauth,
-          has_latest,
-          iap,
-          skip_build,
-      )
-    requires_build = bool(build_from_source) and not skip_build
-    include_validate_service = requires_build and self.ReleaseTrack() in [
-        base.ReleaseTrack.ALPHA,
-        base.ReleaseTrack.BETA,
-    ]
-    deployment_stages = stages.ServiceStages(
-        include_iam_policy_set=allow_unauth is not None,
-        include_route=has_latest,
-        include_validate_service=include_validate_service,
-        include_build=requires_build,
-        include_create_repo=repo_to_create is not None,
-        include_create_revision=True,
-        include_iap=iap is not None,
-    )
-    header = 'Deploying new Multi-Region service...'
-    # new services default cpu boost on the client
-    if not flags.FlagIsExplicitlySet(args, 'cpu_boost'):
-      changes.append(config_changes.StartupCpuBoostChange(cpu_boost=True))
-    return progress_tracker.StagedProgressTracker(
-        header,
-        deployment_stages,
-        failure_message=(
-            'Multi-region deployment failed. Some regions might already be'
-            ' serving traffic.'
-        ),
-        suppress_output=args.async_,
-    )
-
-  def Run(self, args):
-    """Deploy a container to Cloud Run."""
-    # If this is a multi-region Service, we will use the global endpoint
-    # for all operations, and append a regions annotation to the Service.
-    self.__is_multi_region = flags.GetMultiRegion(args)
-    return super().Run(args)
-
 
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA)
 class AlphaDeploy(BetaDeploy):
   """Create or update a Cloud Run service."""
 
+  def _ValidateNoAutomaticUpdatesForContainers(
+      self, deploy_from_source, containers
+  ):
+    for name, container in containers.items():
+      if container.IsSpecified('automatic_updates') and (
+          name not in deploy_from_source or container.IsSpecified('no_build')
+      ):
+        raise c_exceptions.InvalidArgumentException(
+            '--automatic-updates',
+            '--automatic-updates can only be specified in the container that'
+            ' builds from source.',
+        )
+
   @classmethod
   def Args(cls, parser):
     cls.CommonArgs(parser)
@@ -1255,10 +1225,6 @@ class AlphaDeploy(BetaDeploy):
     flags.AddDeployHealthCheckFlag(parser)
     flags.AddIapFlag(parser)
     flags.AddRuntimeFlag(parser)
-    flags.AddServiceMaxInstancesFlag(parser)
-    flags.AddMaxSurgeFlag(parser)
-    flags.AddMaxUnavailableFlag(parser)
-    flags.AddRegionsArg(parser)
     flags.SERVICE_MESH_FLAG.AddToParser(parser)
     flags.IDENTITY_FLAG.AddToParser(parser)
     flags.ENABLE_WORKLOAD_CERTIFICATE_FLAG.AddToParser(parser)
@@ -1268,7 +1234,7 @@ class AlphaDeploy(BetaDeploy):
     container_parser.AddContainerFlags(parser, container_args)
     flags.AddDelegateBuildsFlag(parser)
     flags.AddOverflowScalingFlag(parser)
-    flags.AddPresetFlag(parser)
+    flags.AddPresetFlags(parser)
 
 
 AlphaDeploy.__doc__ = Deploy.__doc__
