@@ -20,6 +20,7 @@ from googlecloudsdk.command_lib.run import config_changes as config_changes_mod
 from googlecloudsdk.command_lib.run import container_parser
 from googlecloudsdk.command_lib.run import exceptions
 from googlecloudsdk.command_lib.run import flags
+from googlecloudsdk.command_lib.run import messages_util
 from googlecloudsdk.command_lib.run import pretty_print
 from googlecloudsdk.command_lib.run import resource_args
 from googlecloudsdk.command_lib.run import resource_name_conversion
@@ -52,8 +53,11 @@ Container Flags
   group.AddArgument(flags.AddVolumeMountFlag())
   group.AddArgument(flags.RemoveVolumeMountFlag())
   group.AddArgument(flags.ClearVolumeMountsFlag())
-  # ALPHA features
-  if release_track == base.ReleaseTrack.ALPHA:
+  # ALPHA and BETA features
+  if (
+      release_track == base.ReleaseTrack.ALPHA
+      or release_track == base.ReleaseTrack.BETA
+  ):
     group.AddArgument(flags.GpuFlag())
 
   return group
@@ -105,6 +109,8 @@ class Update(base.Command):
     flags.AddServiceAccountFlag(parser)
     flags.AddClientNameAndVersionFlags(parser)
     flags.AddNoPromoteFlag(parser)
+    flags.AddGpuTypeFlag(parser)
+    flags.GpuZonalRedundancyFlag(parser)
     worker_pool_presentation = presentation_specs.ResourcePresentationSpec(
         'WORKER_POOL',
         resource_args.GetV2WorkerPoolResourceSpec(prompt=True),
@@ -121,7 +127,7 @@ class Update(base.Command):
   @classmethod
   def Args(cls, parser):
     cls.CommonArgs(parser)
-    container_args = ContainerArgGroup()
+    container_args = ContainerArgGroup(cls.ReleaseTrack())
     container_parser.AddContainerFlags(parser, container_args)
 
   def _AssertChanges(self, changes, flags_text, ignore_empty):
@@ -172,6 +178,7 @@ class Update(base.Command):
         run_client
     )
     worker_pool = worker_pools_client.GetWorkerPool(worker_pool_ref)
+    messages_util.MaybeLogDefaultGpuTypeMessageForV2Resource(args, worker_pool)
     config_changes = self._GetBaseChanges(args)
     if worker_pool:
       header = 'Updating...'
@@ -230,12 +237,8 @@ class AlphaUpdate(Update):
   @classmethod
   def Args(cls, parser):
     cls.CommonArgs(parser)
-    flags.AddMaxSurgeFlag(parser, resource_kind='worker')
-    flags.AddMaxUnavailableFlag(parser, resource_kind='worker')
     flags.AddWorkerPoolMinInstancesFlag(parser)
     flags.AddWorkerPoolMaxInstancesFlag(parser)
-    flags.AddGpuTypeFlag(parser)
-    flags.GpuZonalRedundancyFlag(parser)
     container_args = ContainerArgGroup(cls.ReleaseTrack())
     container_parser.AddContainerFlags(parser, container_args)
 
